package com.example.produceItemService.controller;

import com.example.produceItemService.entity.Item;
import com.example.produceItemService.service.ItemService;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RequiredArgsConstructor
@RestController
@RequestMapping("/Items")
public class ItemController {

    private final ItemService itemService;

    @PostMapping
    @ResponseStatus(HttpStatus.CREATED)
    public Mono<Item> create(@RequestBody Item Item){
        return itemService.createItem(Item);
    }

    @GetMapping
    public Flux<Item> getAllItems(){
        return itemService.getAllItems();
    }

    @PutMapping("/{ItemId}")
    public Mono<ResponseEntity<Item>> updateItemById(@PathVariable Integer ItemId, @RequestBody Item Item){
        return itemService.updateItem(ItemId,Item)
                .map(ResponseEntity::ok)
                .defaultIfEmpty(ResponseEntity.badRequest().build());
    }

    @DeleteMapping("/{ItemId}")
    public Mono<ResponseEntity<Void>> deleteItemById(@PathVariable Integer ItemId){
        return itemService.deleteItem(ItemId)
                .map( r -> ResponseEntity.ok().<Void>build())
                .defaultIfEmpty(ResponseEntity.notFound().build());
    }

    @PostMapping("/produce")
    public Mono<ResponseEntity<Item>> produceItem(@RequestBody Item Item){
        return itemService.produceItem(Item).map(ResponseEntity::ok);
    }

//    @GetMapping("/produce/{ItemId}")
//    public Mono<ResponseEntity<Item>> produceItem(@PathVariable Integer ItemId){
//        return itemService.produceItem(Item).map(ResponseEntity::ok);
//    }

}
